@@ -52,13 +52,28 @@ class CarPartSegmentationConfig(BaseConfig):
 
     index_to_category: Optional[Dict[int, str]] = field(
         default_factory=lambda: {
-            i: cat for i, cat in enumerate([
-                'Back-bumper','Back-door','Back-wheel','Back-window','Back-windshield','Fender',
-                'Front-bumper','Front-door','Front-wheel','Front-window','Grille','Headlight',
-                'Hood','License-plate','Mirror','Quarter-panel','Rocker-panel','Roof','Tail-light',
-                'Trunk','Windshield'
-            ])
-        }
+            0: 'Back-wheel', 
+            1: 'Back-window', 
+            2: 'Back-door', 
+            3: 'Mirror', 
+            4: 'License-plate', 
+            5: 'Grille', 
+            6: 'Front-bumper', 
+            7: 'Hood', 
+            8: 'Headlight', 
+            9: 'Front-wheel', 
+            10: 'Fender', 
+            11: 'Front-window', 
+            12: 'Front-door', 
+            13: 'Rocker-panel', 
+            14: 'Quarter-panel', 
+            15: 'Back-bumper', 
+            16: 'Roof', 
+            17: 'Windshield', 
+            18: 'Trunk', 
+            19: 'Tail-light', 
+            20: 'Back-windshield'
+            }
     )
 
 
