@@ -35,8 +35,8 @@ class PPEComplianceConfig(BaseConfig):
     ])
     alert_config: Optional[AlertConfig] = None
     index_to_category: Optional[Dict[int, str]] = field(default_factory=lambda: {
-        0: 'Hardhat', 1: 'Mask', 2: 'NO-Hardhat', 3: 'NO-Mask', 4: 'NO-Safety Vest',
-        5: 'Person', 6: 'Safety Cone', 7: 'Safety Vest', 8: 'machinery', 9: 'vehicle'
+        -1: 'Hardhat', 0: 'Mask', 1: 'NO-Hardhat', 2: 'NO-Mask', 3: 'NO-Safety Vest',
+        4: 'Person', 5: 'Safety Cone', 6: 'Safety Vest', 7: 'machinery', 8: 'vehicle'
     })
 
 class PPEComplianceUseCase(BaseProcessor):
@@ -261,22 +261,18 @@ class PPEComplianceUseCase(BaseProcessor):
         """
         Main entry point for PPE compliance detection post-processing.
         Applies category mapping, violation smoothing, counting, alerting, and summary generation.
-        Returns a ProcessingResult with all relevant outputs.
+        Returns a ProcessingResult with all relevant outputs in the new agg_summary format
         """
         start_time = time.time()
-        # Ensure config is correct type
         if not isinstance(config, PPEComplianceConfig):
             return self.create_error_result("Invalid config type", usecase=self.name, category=self.category, context=context)
         if context is None:
             context = ProcessingContext()
 
-        # Detect input format and store in context
         input_format = match_results_structure(data)
         context.input_format = input_format
         context.no_hardhat_threshold = config.no_hardhat_threshold
 
-
-
         # Map detection indices to category names robustly (PPE only)
         processed_data = self._robust_apply_category_mapping(data, config.index_to_category)
         # Only keep violation categories (remove 'Person', etc.)
@@ -294,51 +290,29 @@ class PPEComplianceUseCase(BaseProcessor):
                     enable_smoothing=True
                 )
                 self.smoothing_tracker = BBoxSmoothingTracker(smoothing_config)
-            smoothed_violations = bbox_smoothing(processed_data, self.smoothing_tracker.config, self.smoothing_tracker)
-            processed_data = smoothed_violations
+            processed_data = bbox_smoothing(processed_data, self.smoothing_tracker.config, self.smoothing_tracker)
 
         # Advanced tracking (BYTETracker-like)
         try:
             from ..advanced_tracker import AdvancedTracker
             from ..advanced_tracker.config import TrackerConfig
-            
-            # Create tracker instance if it doesn't exist (preserves state across frames)
             if self.tracker is None:
                 tracker_config = TrackerConfig()
                 self.tracker = AdvancedTracker(tracker_config)
                 self.logger.info("Initialized AdvancedTracker for PPE compliance tracking")
-            
-            # The tracker expects the data in the same format as input
-            # It will add track_id and frame_id to each detection
             processed_data = self.tracker.update(processed_data)
-            
         except Exception as e:
-            # If advanced tracker fails, fallback to unsmoothed detections
             self.logger.warning(f"AdvancedTracker failed: {e}")
 
-        # Deduplicate overlapping violations (same label, high IoU)
-        # processed_data = self._deduplicate_violations(processed_data, iou_thresh=0.92)
-
-        # Update violation tracking state for total count per label
         self._update_violation_tracking_state(processed_data)
-        
-        # Update frame counter
         self._total_frame_counter += 1
 
-        # Extract frame information from stream_info
-        frame_number = None
-        if stream_info:
-            input_settings = stream_info.get("input_settings", {})
-            start_frame = input_settings.get("start_frame")
-            end_frame = input_settings.get("end_frame")
-            # If start and end frame are the same, it's a single frame
-            if start_frame is not None and end_frame is not None and start_frame == end_frame:
-                frame_number = start_frame
+        # Frame number logic (not chunkwise, just per call)
+        frame_number = self._total_frame_counter
 
         # Compute summaries and alerts
         general_counting_summary = calculate_counting_summary(data)
         counting_summary = self._count_categories(processed_data, config)
-        # Add total unique violation counts after tracking using only local state
         total_violation_counts = self.get_total_violation_counts()
         counting_summary['total_violation_counts'] = total_violation_counts
         insights = self._generate_insights(counting_summary, config)
@@ -346,26 +320,48 @@ class PPEComplianceUseCase(BaseProcessor):
         predictions = self._extract_predictions(processed_data)
         summary = self._generate_summary(counting_summary, alerts)
 
-        # Step: Generate structured events and tracking stats with frame-based keys
+        # Generate new-format output (agg_summary)
         events_list = self._generate_events(counting_summary, alerts, config, frame_number, stream_info)
         tracking_stats_list = self._generate_tracking_stats(counting_summary, insights, summary, config, frame_number, stream_info)
-
-        # Extract frame-based dictionaries from the lists
+        # No business_analytics for PPE, but keep key for compatibility
+        business_analytics = {}
         events = events_list[0] if events_list else {}
         tracking_stats = tracking_stats_list[0] if tracking_stats_list else {}
 
-        context.mark_completed()
+        # Compose new human_text dict for agg_summary
+        app_name = "ppe_compliance"
+        app_version = "1.2"
+        # Get incident human_text (first event if present)
+        incident_human_text = ""
+        if isinstance(events, list) and events and isinstance(events[0], dict):
+            incident_human_text = events[0].get("human_text", "")
+        elif isinstance(events, dict):
+            incident_human_text = events.get("human_text", "")
+        # Get tracking statistics human_text
+        tracking_human_text = ""
+        if isinstance(tracking_stats, dict):
+            tracking_human_text = tracking_stats.get("human_text", "")
+        elif isinstance(tracking_stats, list) and tracking_stats and isinstance(tracking_stats[0], dict):
+            tracking_human_text = tracking_stats[0].get("human_text", "")
 
-        # Build result object
+        agg_human_text = {
+            "Application Name": app_name,
+            "Application Version": app_version,
+            "Incidents:": incident_human_text,
+            "Tracking Statistics:": tracking_human_text
+        }
+
+        agg_summary = {str(frame_number): {
+            "incidents": events,
+            "tracking_stats": tracking_stats,
+            "business_analytics": business_analytics,
+            "alerts": alerts,
+            "human_text": agg_human_text
+        }}
+
+        context.mark_completed()
         result = self.create_result(
-            data={
-                "counting_summary": counting_summary,
-                "general_counting_summary": general_counting_summary,
-                "alerts": alerts,
-                "total_violations": counting_summary.get("total_count", 0),
-                "events": events,
-                "tracking_stats": tracking_stats,
-            },
+            data={"agg_summary": agg_summary},
             usecase=self.name,
             category=self.category,
             context=context
@@ -423,15 +419,9 @@ class PPEComplianceUseCase(BaseProcessor):
         frame_events = events[0][frame_key]
         total_violations = counting_summary.get("total_count", 0)
 
-        # Generate human text in new format
-        human_text_lines = ["EVENTS DETECTED:"]
-        if total_violations > 0:
-            human_text_lines.append(f"    - {total_violations} PPE violation(s) detected [INFO]")
-        else:
-            human_text_lines.append("    - No PPE violations detected")
-        human_text = "\n".join(human_text_lines)
-
+        # Generate human text in new format for incidents (match people_counting/mask_detection)
         if total_violations > 0:
+            human_text = f"INCIDENTS DETECTED @ :\n\tSeverity Level: ('ppe_compliance', 'info')"
             event = {
                 "type": "ppe_violation",
                 "severity": "info",
@@ -442,6 +432,18 @@ class PPEComplianceUseCase(BaseProcessor):
                 "human_text": human_text
             }
             frame_events.append(event)
+        else:
+            human_text = "INCIDENTS DETECTED @ :\n\tSeverity Level: ('ppe_compliance', 'none')"
+            event = {
+                "type": "ppe_violation",
+                "severity": "none",
+                "category": "ppe",
+                "count": 0,
+                "timestamp": datetime.now(timezone.utc).strftime('%Y-%m-%d-%H:%M:%S UTC'),
+                "location_info": None,
+                "human_text": human_text
+            }
+            frame_events.append(event)
         # Add alert events
         for alert in alerts:
             alert_event = {
